@@ -372,7 +372,7 @@ As well as some PostgreSQL specific extensions added by L<SQL::Abstract::Pg>.
 Including operations commonly referred to as C<upsert>.
 
   # "insert into t (a) values ('b') on conflict (a) do update set a = 'c'"
-  $db->insert('t', {a => 'b'}, {on_conflict => [['a'], {a => 'c'}]);
+  $db->insert('t', {a => 'b'}, {on_conflict => [a => {a => 'c'}]});
 
 =head2 insert_p
 
@@ -502,17 +502,19 @@ L<SQL::Abstract>.
 
 As well as some PostgreSQL specific extensions added by L<SQL::Abstract::Pg>.
 
+  # "select * from foo join bar on (bar.foo_id = foo.id)"
+  $db->select(['foo', ['bar', foo_id => 'id']]);
+
+  # "select * from foo left join bar on (bar.foo_id = foo.id)"
+  $db->select(['foo', [-left => 'bar', foo_id => 'id']]);
+
   # "select foo as bar from some_table"
   $db->select('some_table', [[foo => 'bar']]);
 
   # "select extract(epoch from foo) as foo, bar from some_table"
   $db->select('some_table', [\'extract(epoch from foo) as foo', 'bar']);
 
-  # "select * from foo join bar on (bar.foo_id = foo.id)"
-  $db->select(['foo', ['bar', foo_id => 'id']]);
-
-  # "select * from foo left join bar on (bar.foo_id = foo.id)"
-  $db->select(['foo', [-left => 'bar', foo_id => 'id']]);
+Including a new last argument to pass many new options.
 
   # "select * from some_table where foo = 'bar' order by id desc"
   $db->select('some_table', '*', {foo => 'bar'}, {order_by => {-desc => 'id'}});
