@@ -46,12 +46,11 @@ sub _insert_returning {
     $self->_SWITCH_refkind(
       $conflict => {
         ARRAYREF => sub {
-          my ($fields, $set) = @$conflict;
-          puke 'on_conflict value must be in the form [\@fields, \%set]'
-            unless ref $fields eq 'ARRAY' && ref $set eq 'HASH';
+          my ($target, $set) = @$conflict;
+          puke 'on_conflict value must be in the form [$target, \%set]'
+            unless ref $set eq 'HASH';
 
-          $conflict_sql
-            = '(' . join(', ', map { $self->_quote($_) } @$fields) . ')';
+          $conflict_sql = '(' . $self->_quote($target) . ')';
           $conflict_sql .= $self->_sqlcase(' do update set ');
           my ($set_sql, @set_bind) = $self->_update_set_values($set);
           $conflict_sql .= $set_sql;
@@ -205,7 +204,7 @@ SQL with bind values are supported.
 This includes operations commonly referred to as C<upsert>.
 
   # "insert into t (a) values ('b') on conflict (a) do update set a = 'c'"
-  $abstract->insert('t', {a => 'b'}, {on_conflict => [['a'], {a => 'c'}]);
+  $abstract->insert('t', {a => 'b'}, {on_conflict => [a => {a => 'c'}]});
 
   # "insert into t (a) values ('b') on conflict (a) do update set a = 'c'"
   $abstract->insert(
